# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dig_ass_ocr_protos/DigitalAssistantOCR.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,dig_ass_ocr_protos/DigitalAssistantOCR.proto\x12\x0e\x64ig.ass.ocr.v1\"+\n\x1b\x44igitalAssistantOCRResponse\x12\x0c\n\x04Text\x18\x01 \x01(\t\"8\n\x1a\x44igitalAssistantOCRRequest\x12\r\n\x05Image\x18\x01 \x01(\x0c\x12\x0b\n\x03PDF\x18\x02 \x01(\x0c\x32\x81\x01\n\x13\x44igitalAssistantOCR\x12j\n\x0fGetTextResponse\x12*.dig.ass.ocr.v1.DigitalAssistantOCRRequest\x1a+.dig.ass.ocr.v1.DigitalAssistantOCRResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dig_ass_ocr_protos.DigitalAssistantOCR_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIGITALASSISTANTOCRRESPONSE']._serialized_start=64
  _globals['_DIGITALASSISTANTOCRRESPONSE']._serialized_end=107
  _globals['_DIGITALASSISTANTOCRREQUEST']._serialized_start=109
  _globals['_DIGITALASSISTANTOCRREQUEST']._serialized_end=165
  _globals['_DIGITALASSISTANTOCR']._serialized_start=168
  _globals['_DIGITALASSISTANTOCR']._serialized_end=297
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DigitalAssistantOCRResponse(_message.Message):
    __slots__ = ("Text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    Text: str
    def __init__(self, Text: _Optional[str] = ...) -> None: ...

class DigitalAssistantOCRRequest(_message.Message):
    __slots__ = ("Image", "PDF")
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    PDF_FIELD_NUMBER: _ClassVar[int]
    Image: bytes
    PDF: bytes
    def __init__(self, Image: _Optional[bytes] = ..., PDF: _Optional[bytes] = ...) -> None: ...



from dig_ass_ocr_protos.DigitalAssistantOCR_pb2_grpc import DigitalAssistantOCRStub
from dig_ass_ocr_protos.DigitalAssistantOCR_pb2 import (
    DigitalAssistantOCRRequest,
    DigitalAssistantOCRResponse,
)

from .abstract_client import AbstractClient


class OCRClient(AbstractClient):
    def __init__(self, address) -> None:
        super().__init__(address)
        self._stub = DigitalAssistantOCRStub(self._channel)

    def __call__(self, image: bytearray, pdf: bytearray):
        request = DigitalAssistantOCRRequest(Image=image, PDF=pdf)
        response: DigitalAssistantOCRResponse = self._stub.GetTextResponse(request)
        return response.Text
